.. _trojanzoo.utils.tensor:

tensor
=======

.. currentmodule:: trojanzoo.utils.tensor

.. autofunction:: tanh_func
.. autofunction:: atan_func
.. autofunction:: repeat_to_batch
.. autofunction:: add_noise
